summaryrefslogtreecommitdiffstats
path: root/src/dolphin.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/dolphin.h')
-rw-r--r--src/dolphin.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/dolphin.h b/src/dolphin.h
index 1ed1f12..779b5d7 100644
--- a/src/dolphin.h
+++ b/src/dolphin.h
@@ -175,14 +175,14 @@ protected:
* This method is called when it is time for the app to save its
* properties for session management purposes.
*/
- void saveProperties(KConfig*);
+ void saveProperties(TDEConfig*);
/**
* This method is called when this app is restored. The KConfig
* object points to the session management config file that was saved
* with @ref saveProperties
*/
- void readProperties(KConfig*);
+ void readProperties(TDEConfig*);
private slots:
/** Opens an input dialog for creating a new folder. */
@@ -214,13 +214,13 @@ private slots:
* Shows the error information of the job \a job
* in the status bar.
*/
- void slotHandleJobError(KIO::Job* job);
+ void slotHandleJobError(TDEIO::Job* job);
/**
* Indicates in the status bar that the delete operation
* of the job \a job has been finished.
*/
- void slotDeleteFileFinished(KIO::Job* job);
+ void slotDeleteFileFinished(TDEIO::Job* job);
/**
* Updates the state of the 'Undo' menu action dependent
@@ -363,7 +363,7 @@ private slots:
* Adds the undo operation given by \a job
* to the UndoManager.
*/
- void addUndoOperation(KIO::Job* job);
+ void addUndoOperation(TDEIO::Job* job);
void toggleleftSidebar();
@@ -391,7 +391,7 @@ private:
void updateViewProperties(const KURL::List& urls);
void copyURLs(const KURL::List& source, const KURL& dest);
void moveURLs(const KURL::List& source, const KURL& dest);
- void addPendingUndoJob(KIO::Job* job,
+ void addPendingUndoJob(TDEIO::Job* job,
DolphinCommand::Type commandType,
const KURL::List& source,
const KURL& dest);
@@ -175,14 +175,14 @@ protected:
/**
- * This method is called when this app is restored. The KConfig
+ * This method is called when this app is restored. The TDEConfig
* object points to the session management config file that was saved
* with @ref saveProperties